@@ -3,7 +3,7 @@ import fire
 
 from .auth import get_token
 from .dataset_manifest import create_manifest
-from .tasks import create_task
+from .tasks import create_task, upload_images
 
 
 def main() -> None:
@@ -13,5 +13,6 @@ def main() -> None:
             "get-token": get_token,
             "create-task": create_task,
             "create-manifest": create_manifest,
+            "upload-images": upload_images,
         }
     )
